lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Date:   Tue, 15 Mar 2022 22:37:00 +0000
From:   Colin Ian King <colin.i.king@...il.com>
To:     Pali Rohár <pali@...nel.org>,
        Sebastian Reichel <sre@...nel.org>, linux-pm@...r.kernel.org
Cc:     kernel-janitors@...r.kernel.org, linux-kernel@...r.kernel.org
Subject: [PATCH] power: supply: bq2415x: Fix spelling mistake "vender" -> "vendor"

There are several spelling mistakes in comments, function names
and literal strings. Fix these.

Signed-off-by: Colin Ian King <colin.i.king@...il.com>
---
 drivers/power/supply/bq2415x_charger.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/power/supply/bq2415x_charger.c b/drivers/power/supply/bq2415x_charger.c
index 5724001e66b9..b35700071966 100644
--- a/drivers/power/supply/bq2415x_charger.c
+++ b/drivers/power/supply/bq2415x_charger.c
@@ -71,7 +71,7 @@
 #define BQ2415X_BIT_OTG_PL		1
 #define BQ2415X_BIT_OTG_EN		0
 
-/* vender register */
+/* vendor register */
 #define BQ2415X_MASK_VENDER		(BIT(5)|BIT(6)|BIT(7))
 #define BQ2415X_SHIFT_VENDER		5
 #define BQ2415X_MASK_PN			(BIT(3)|BIT(4))
@@ -491,8 +491,8 @@ static int bq2415x_detect_revision(struct bq2415x_device *bq)
 	return -1;
 }
 
-/* return chip vender code */
-static int bq2415x_get_vender_code(struct bq2415x_device *bq)
+/* return chip vendor code */
+static int bq2415x_get_vendor_code(struct bq2415x_device *bq)
 {
 	int ret;
 
@@ -1501,9 +1501,9 @@ static int bq2415x_power_supply_init(struct bq2415x_device *bq)
 		sprintf(revstr, "1.%d", ret);
 
 	bq->model = kasprintf(GFP_KERNEL,
-				"chip %s, revision %s, vender code %.3d",
+				"chip %s, revision %s, vendor code %.3d",
 				bq2415x_chip_name[chip], revstr,
-				bq2415x_get_vender_code(bq));
+				bq2415x_get_vendor_code(bq));
 	if (!bq->model) {
 		dev_err(bq->dev, "failed to allocate model name\n");
 		return -ENOMEM;
-- 
2.35.1

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ